@@ -77,6 +77,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_ec2
@@ -109,6 +111,11 @@ class CapacityProviderStrategyItem:
         :param weight: 
         :param base: 
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CapacityProviderStrategyItem.__init__)
+            check_type(argname="argument capacity_provider", value=capacity_provider, expected_type=type_hints["capacity_provider"])
+            check_type(argname="argument weight", value=weight, expected_type=type_hints["weight"])
+            check_type(argname="argument base", value=base, expected_type=type_hints["base"])
         self._values: typing.Dict[str, typing.Any] = {
             "capacity_provider": capacity_provider,
             "weight": weight,
@@ -154,7 +161,7 @@ class EksClusterOptions:
     def __init__(
         self,
         *,
-        cluster_options: aws_cdk.aws_eks.ClusterProps,
+        cluster_options: typing.Union[aws_cdk.aws_eks.ClusterProps, typing.Dict[str, typing.Any]],
         rbac: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
@@ -163,6 +170,10 @@ class EksClusterOptions:
         '''
         if isinstance(cluster_options, dict):
             cluster_options = aws_cdk.aws_eks.ClusterProps(**cluster_options)
+        if __debug__:
+            type_hints = typing.get_type_hints(EksClusterOptions.__init__)
+            check_type(argname="argument cluster_options", value=cluster_options, expected_type=type_hints["cluster_options"])
+            check_type(argname="argument rbac", value=rbac, expected_type=type_hints["rbac"])
         self._values: typing.Dict[str, typing.Any] = {
             "cluster_options": cluster_options,
         }
@@ -220,8 +231,8 @@ class FargateEksClusterOptions:
     def __init__(
         self,
         *,
-        cluster_options: aws_cdk.aws_eks.FargateClusterProps,
-        helm_runner_options: typing.Optional["HelmRunnerOptions"] = None,
+        cluster_options: typing.Union[aws_cdk.aws_eks.FargateClusterProps, typing.Dict[str, typing.Any]],
+        helm_runner_options: typing.Optional[typing.Union["HelmRunnerOptions", typing.Dict[str, typing.Any]]] = None,
         rbac: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
@@ -233,6 +244,11 @@ class FargateEksClusterOptions:
             cluster_options = aws_cdk.aws_eks.FargateClusterProps(**cluster_options)
         if isinstance(helm_runner_options, dict):
             helm_runner_options = HelmRunnerOptions(**helm_runner_options)
+        if __debug__:
+            type_hints = typing.get_type_hints(FargateEksClusterOptions.__init__)
+            check_type(argname="argument cluster_options", value=cluster_options, expected_type=type_hints["cluster_options"])
+            check_type(argname="argument helm_runner_options", value=helm_runner_options, expected_type=type_hints["helm_runner_options"])
+            check_type(argname="argument rbac", value=rbac, expected_type=type_hints["rbac"])
         self._values: typing.Dict[str, typing.Any] = {
             "cluster_options": cluster_options,
         }
@@ -307,6 +323,10 @@ class FargateJobExecutor(
         :param security_group: 
         :param subnet: 
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(FargateJobExecutor.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = FargateJobExecutorProps(
             cluster=cluster,
             image=image,
@@ -373,6 +393,13 @@ class FargateJobExecutorProps:
         :param security_group: 
         :param subnet: 
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(FargateJobExecutorProps.__init__)
+            check_type(argname="argument cluster", value=cluster, expected_type=type_hints["cluster"])
+            check_type(argname="argument image", value=image, expected_type=type_hints["image"])
+            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
+            check_type(argname="argument security_group", value=security_group, expected_type=type_hints["security_group"])
+            check_type(argname="argument subnet", value=subnet, expected_type=type_hints["subnet"])
         self._values: typing.Dict[str, typing.Any] = {}
         if cluster is not None:
             self._values["cluster"] = cluster
@@ -437,14 +464,14 @@ class FargateRunner(
         id: builtins.str,
         *,
         vpc: aws_cdk.aws_ec2.IVpc,
-        cluster_default_capacity_provider_strategy: typing.Optional[typing.Sequence[CapacityProviderStrategyItem]] = None,
+        cluster_default_capacity_provider_strategy: typing.Optional[typing.Sequence[typing.Union[CapacityProviderStrategyItem, typing.Dict[str, typing.Any]]]] = None,
         executor: typing.Optional[FargateJobExecutor] = None,
-        fargate_job_subnet: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        fargate_job_subnet: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
         gitlab_url: typing.Optional[builtins.str] = None,
         image: typing.Optional["JobRunnerImage"] = None,
         registration_token: typing.Optional[builtins.str] = None,
         security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
-        service_default_capacity_provider_strategy: typing.Optional[typing.Sequence[CapacityProviderStrategyItem]] = None,
+        service_default_capacity_provider_strategy: typing.Optional[typing.Sequence[typing.Union[CapacityProviderStrategyItem, typing.Dict[str, typing.Any]]]] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
         '''
@@ -461,6 +488,10 @@ class FargateRunner(
         :param service_default_capacity_provider_strategy: Default capacity provider strategy for the Amazon ECS service. Default: DEFAULT_SERVICE_CAPACITY_PROVIDER_STRATEGY
         :param tags: tags for the runner.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(FargateRunner.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = FargateRunnerProps(
             vpc=vpc,
             cluster_default_capacity_provider_strategy=cluster_default_capacity_provider_strategy,
@@ -503,14 +534,14 @@ class FargateRunnerProps:
         self,
         *,
         vpc: aws_cdk.aws_ec2.IVpc,
-        cluster_default_capacity_provider_strategy: typing.Optional[typing.Sequence[CapacityProviderStrategyItem]] = None,
+        cluster_default_capacity_provider_strategy: typing.Optional[typing.Sequence[typing.Union[CapacityProviderStrategyItem, typing.Dict[str, typing.Any]]]] = None,
         executor: typing.Optional[FargateJobExecutor] = None,
-        fargate_job_subnet: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        fargate_job_subnet: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
         gitlab_url: typing.Optional[builtins.str] = None,
         image: typing.Optional["JobRunnerImage"] = None,
         registration_token: typing.Optional[builtins.str] = None,
         security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
-        service_default_capacity_provider_strategy: typing.Optional[typing.Sequence[CapacityProviderStrategyItem]] = None,
+        service_default_capacity_provider_strategy: typing.Optional[typing.Sequence[typing.Union[CapacityProviderStrategyItem, typing.Dict[str, typing.Any]]]] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
         '''Properties for the FargateRunner.
@@ -528,6 +559,18 @@ class FargateRunnerProps:
         '''
         if isinstance(fargate_job_subnet, dict):
             fargate_job_subnet = aws_cdk.aws_ec2.SubnetSelection(**fargate_job_subnet)
+        if __debug__:
+            type_hints = typing.get_type_hints(FargateRunnerProps.__init__)
+            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
+            check_type(argname="argument cluster_default_capacity_provider_strategy", value=cluster_default_capacity_provider_strategy, expected_type=type_hints["cluster_default_capacity_provider_strategy"])
+            check_type(argname="argument executor", value=executor, expected_type=type_hints["executor"])
+            check_type(argname="argument fargate_job_subnet", value=fargate_job_subnet, expected_type=type_hints["fargate_job_subnet"])
+            check_type(argname="argument gitlab_url", value=gitlab_url, expected_type=type_hints["gitlab_url"])
+            check_type(argname="argument image", value=image, expected_type=type_hints["image"])
+            check_type(argname="argument registration_token", value=registration_token, expected_type=type_hints["registration_token"])
+            check_type(argname="argument security_group", value=security_group, expected_type=type_hints["security_group"])
+            check_type(argname="argument service_default_capacity_provider_strategy", value=service_default_capacity_provider_strategy, expected_type=type_hints["service_default_capacity_provider_strategy"])
+            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
         self._values: typing.Dict[str, typing.Any] = {
             "vpc": vpc,
         }
@@ -667,6 +710,14 @@ class HelmRunnerOptions:
         :param registration_token: GitLab registration token for the runner, you put registrationToken in cdk.context.json like "GITLAB_REGISTRATION_TOKEN": "xxxxxxx".
         :param tags: tags for the runner. Default: - ['eks', 'fargate', 'runner']
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(HelmRunnerOptions.__init__)
+            check_type(argname="argument concurrent", value=concurrent, expected_type=type_hints["concurrent"])
+            check_type(argname="argument gitlab_url", value=gitlab_url, expected_type=type_hints["gitlab_url"])
+            check_type(argname="argument job_default_image", value=job_default_image, expected_type=type_hints["job_default_image"])
+            check_type(argname="argument namespace", value=namespace, expected_type=type_hints["namespace"])
+            check_type(argname="argument registration_token", value=registration_token, expected_type=type_hints["registration_token"])
+            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
         self._values: typing.Dict[str, typing.Any] = {}
         if concurrent is not None:
             self._values["concurrent"] = concurrent
@@ -759,6 +810,9 @@ class JobExecutorImage(
 
         :param image: custom image registry URI.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(JobExecutorImage.of)
+            check_type(argname="argument image", value=image, expected_type=type_hints["image"])
         return typing.cast("JobExecutorImage", jsii.sinvoke(cls, "of", [image]))
 
     @jsii.python.classproperty # type: ignore[misc]
@@ -804,6 +858,9 @@ class JobRunnerImage(metaclass=jsii.JSIIMeta, jsii_type="cdk-gitlab.JobRunnerIma
 
         :param image: custom image registry URI.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(JobRunnerImage.of)
+            check_type(argname="argument image", value=image, expected_type=type_hints["image"])
         return typing.cast("JobRunnerImage", jsii.sinvoke(cls, "of", [image]))
 
     @jsii.python.classproperty # type: ignore[misc]
@@ -840,6 +897,10 @@ class Provider(
         :param id: -
         :param vpc: 
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Provider.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ProviderProps(vpc=vpc)
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -850,7 +911,7 @@ class Provider(
         scope: constructs.Construct,
         id: builtins.str,
         *,
-        cluster_options: aws_cdk.aws_eks.ClusterProps,
+        cluster_options: typing.Union[aws_cdk.aws_eks.ClusterProps, typing.Dict[str, typing.Any]],
         rbac: typing.Optional[builtins.bool] = None,
     ) -> aws_cdk.aws_eks.Cluster:
         '''
@@ -859,6 +920,10 @@ class Provider(
         :param cluster_options: cluster properties for Amazon EKS cluster.
         :param rbac: create serivce account and rbac ClusterRoleBinding for gitlab. Default: true
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Provider.create_eks_cluster)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = EksClusterOptions(cluster_options=cluster_options, rbac=rbac)
 
         return typing.cast(aws_cdk.aws_eks.Cluster, jsii.invoke(self, "createEksCluster", [scope, id, props]))
@@ -873,8 +938,8 @@ class Provider(
         scope: constructs.Construct,
         id: builtins.str,
         *,
-        cluster_options: aws_cdk.aws_eks.FargateClusterProps,
-        helm_runner_options: typing.Optional[HelmRunnerOptions] = None,
+        cluster_options: typing.Union[aws_cdk.aws_eks.FargateClusterProps, typing.Dict[str, typing.Any]],
+        helm_runner_options: typing.Optional[typing.Union[HelmRunnerOptions, typing.Dict[str, typing.Any]]] = None,
         rbac: typing.Optional[builtins.bool] = None,
     ) -> aws_cdk.aws_eks.Cluster:
         '''
@@ -884,6 +949,10 @@ class Provider(
         :param helm_runner_options: Gitlab helm Chart runner install Options. see https://docs.gitlab.com/runner/install/kubernetes.html
         :param rbac: create serivce account and rbac ClusterRoleBinding for gitlab. Default: true
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Provider.create_fargate_eks_cluster)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = FargateEksClusterOptions(
             cluster_options=cluster_options,
             helm_runner_options=helm_runner_options,
@@ -900,6 +969,9 @@ class Provider(
         '''
         :param executor: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Provider.create_fargate_runner)
+            check_type(argname="argument executor", value=executor, expected_type=type_hints["executor"])
         return typing.cast(None, jsii.invoke(self, "createFargateRunner", [executor]))
 
     @jsii.member(jsii_name="createGitlabManagedEksRole")
@@ -933,6 +1005,9 @@ class Provider(
 
     @gitlab_eks_role.setter
     def gitlab_eks_role(self, value: typing.Optional[aws_cdk.aws_iam.IRole]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(Provider, "gitlab_eks_role").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "gitlabEksRole", value)
 
 
@@ -946,6 +1021,9 @@ class ProviderProps:
         '''
         :param vpc: 
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ProviderProps.__init__)
+            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
         self._values: typing.Dict[str, typing.Any] = {}
         if vpc is not None:
             self._values["vpc"] = vpc
@@ -978,6 +1056,10 @@ class RoleProps:
         :param account_id: 
         :param external_id: 
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RoleProps.__init__)
+            check_type(argname="argument account_id", value=account_id, expected_type=type_hints["account_id"])
+            check_type(argname="argument external_id", value=external_id, expected_type=type_hints["external_id"])
         self._values: typing.Dict[str, typing.Any] = {
             "account_id": account_id,
             "external_id": external_id,
